/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.util.Iterator;
import java.util.List;

// Generated classes
import samples.dtd.Artist;
import samples.dtd.Song;
import samples.dtd.Songs;
import samples.dtd.SongsUnmarshaller;

public class TestSongsDTD {

    public static void main(String[] args) {
        if (args.length != 1) {
            System.out.println("Usage: java samples.TestSongsDTD " +
                "[songs.xml location]");
            return;
        }

        // Turn on validation
        System.setProperty("org.enhydra.zeus.validation", "true");

        // Set the XML parser to use
        String xmlParser = System.getProperty("org.xml.sax.driver");
        if ((xmlParser == null) || (xmlParser.equals(""))) {
            System.setProperty("org.xml.sax.driver", 
                               "org.apache.xerces.parsers.SAXParser");
        }

        try {
            // New way of unmarshalling
            Songs songs = SongsUnmarshaller.unmarshal(new File(args[0]), false);

            List songList = songs.getSongList();
            for (Iterator i = songList.iterator(); i.hasNext(); ) {
                Song song = (Song)i.next();
                System.out.println("Song title: '" + 
                    song.getTitle() + "'");
                List artists = song.getArtistList();
                for (Iterator j = artists.iterator(); j.hasNext(); ) {
                    Artist artist = (Artist)j.next();
                    System.out.println("Artist: '" + artist.getValue() + "'");
                    System.out.println("  Type: '" + artist.getType() + "'");
                }
                System.out.println("-------------------------");
            }
            
            for (Iterator i = songList.iterator(); i.hasNext(); ) {
                Song song = (Song)i.next();
                
                // Rename songs named 'The Finishing Touch' to 'Call It A Day'
                if (song.getTitle().equals("The Finishing Touch")) {
                    song.setTitle("Call It A Day");
                }
            }

            // New way of marshalling
            songs.marshal(new File("output.xml"));
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
