/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.transform;

/**
 * <p>
 *  <code>NoSuchValueEnumerationException</code> is an extension of 
 *    <code>{@link TransformerException}</code> that provides information
 *    about a missing <code>{@link ValueEnumeration}</code> that has been
 *    requested, generally by name.
 * </p>
 * 
 * @author Brett McLaughlin
 */
public class NoSuchValueEnumerationException extends TransformerException {
    
    /**
     * <p>
     *  This will create a <code>NoSuchValueEnumerationException</code> 
     *    indicating the name of the <code>{@link ValueEnumeration}</code> 
     *    being searched for, and that was not found.
     * </p>
     *
     * @param name the name of the requested enumeration
     */    
    public NoSuchValueEnumerationException(String name)  {
        super("A ValueEnumeration with the name '" + name + 
            "' could not be found in the Transformer.");
    }
}
