/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package org.enhydra.zeus.util;

/**
 * <p>
 *  <code>XMLName</code> is a small (private) utility class to hold the 
 *    pair of strings used to identify a binding to ignore.
 * </p>
 *
 * @author Brett McLaughlin
 * @author Sean Ogle
 */
public class XMLName {

    /** The XML name of the class */
    private String xmlName;
    
    /** The URI for this XML name */
    private String namespaceURI;
    
    /**
     * <p>
     *  This allows construction of a new XML named item.
     * </p>
     *
     * @param xmlName the name of the XML item
     * @param namespaceURI the namespace URI for this item
     */
    public XMLName(String xmlName, String namespaceURI) {
        this.xmlName = xmlName;
        this.namespaceURI = namespaceURI;
    }
    
    /**
     * <p>
     *  This sets the XML name for this item.
     * </p>
     *
     * @param xmlName the name of the XML item.
     */
     public void setXMLName(String xmlName) {
         this.xmlName = xmlName;
     }
     
     /**
      * <p>
      *  This returns the XML name of this item.
      * </p>
      *
      * @return <code>String</code> - this item's XML name
      */
     public String getXMLName() {
         return xmlName;
     }
     
    /**
     * <p>
     *  This sets the URI for this item.
     * </p>
     *
     * @param namespaceURI the namespace URI
     */
     public void setNamespaceURI(String namespaceURI) {
         this.namespaceURI = namespaceURI;
     }
     
     /**
      * <p>
      *  This returns the namespace URI of this item.
      * </p>
      *
      * @return <code>String</code> - this item's namespace URI
      */
     public String getNamespaceURI() {
         return namespaceURI;
     }     
}
